@@ -233,16 +233,15 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None,
     if tempdir == None:
         m = hashlib.sha1()
         m.update("\n".join(command_sig))
-        basename = os.path.join("temp", "." + base64.b64encode(m.digest(), "+="), '')
+        basename = os.path.join("temp", "." + base64.b64encode(m.digest(),
+            "_-").strip("="), '')
     else: basename = tempdir
 
     if env.GetOption("clean") and basename:
         if os.path.exists(basename): env.Execute(Delete(basename))
     elif execute:
         if not os.path.exists(basename): mkdir_p(basename)
-        scons = os.path.join(basename, "SConscript")
-        file = open(scons, 'w')
-        print >>file, """from pyscons import *
+        scons = """from pyscons import *
 targets, sources, basename = PySconsSetup()
 
 env = DefaultEnvironment()
@@ -256,28 +255,19 @@ command += ["mv %%s %%s" %% (s, t) for s,t in zip(stargets, targets)]
 gen = lambda source, target, env, for_signature: command_sig if for_signature else command
 PyScript(targets, sources, CommandGeneratorAction(gen,{}), clean=False)
 """ % (repr(command_sig), repr(command))
-        file.close()
 
         arg = " ".join(["in%g=%s" % (n+1, str(s)) for n,s in enumerate(source)])
         arg += " " + " ".join(["out%g=%s" % (n+1, str(s)) for n,s in enumerate(target)])
-        vars = " temp=" + basename + " n=" + scons
+        vars = " temp=" + basename
 
         exe = os.path.join(basename, "EXECUTE")
         file = open(exe, 'w')
-        print >>file, "#!/bin/bash\nscons %s -f%s %s $*" % (vars, scons, arg)
+        comments = "\n".join(["#TARGET\t%s" % s for s in target] + ["#SOURCE\t%s"
+            %s for s in source + [exe]])
+        print >>file, "#!/usr/bin/env scons %s %s -f\n%s\n%s" % (vars, arg, comments, scons)
         os.chmod(exe, 0755)
         file.close()
 
-        ts = os.path.join(basename, "TARGETS")
-        file = open(ts, 'w')
-        print >>file, "\n".join(target)
-        file.close()
-
-        ss = os.path.join(basename, "SOURCES")
-        file = open(ss, 'w')
-        print >>file, "\n".join(source + [scons, exe, ss, ts])
-        file.close()
-
         if not lightweight: command = exe + " -Q"
 
     if execute: command = [execute + " " + basename]
@@ -304,32 +294,24 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q",
     if tempdir == None:
         m = hashlib.sha1()
         m.update(sig)
-        basename = os.path.join("temp", "." + base64.b64encode(m.digest(), "+="), '')
+        basename = os.path.join("temp", "." + base64.b64encode(m.digest(),
+            "-_").strip("="), '')
     else: basename = tempdir
 
     USE_DIR = tuple(os.path.split(basename))
     if USE_DIR in _USED_DIRS: raise ValueError("Cannot use temp directory %s in more than one PyScript or PyScons." % basename)
     else: _USED_DIRS.add(USE_DIR)
 
-    vars = " temp=" + basename + " n=" + scons
+    vars = " temp=" + basename
 
     if not os.path.exists(basename): mkdir_p(basename)
     exe = os.path.join(basename, "EXECUTE")
     file = open(exe, 'w')
-    print >>file, "#!/bin/bash\nscons %s %s -f%s %s $*" % (vars, sig_options, scons, args)
+    comments = "\n".join(["#TARGET\t%s" % s for s in target] + ["#SOURCE\t%s" %s for s in source + [scons, exe]])
+    print >>file, "#!/bin/bash\n%s\nscons %s %s -f%s %s $*" % (comments, vars, sig_options, scons, args)
     os.chmod(exe, 0755)
     file.close()
 
-    ts = os.path.join(basename, "TARGETS")
-    file = open(ts, 'w')
-    print >>file, "\n".join(target)
-    file.close()
-
-    ss = os.path.join(basename, "SOURCES")
-    file = open(ss, 'w')
-    print >>file, "\n".join(source + [scons, ts, ss, exe])
-    file.close()
-
     if "exit" in ARGUMENTS: options += " -k exit=%s" % ARGUMENTS["exit"]
     cmd = " ".join([exe, options])
     cleancmd = cmd + " --clean"
@@ -386,7 +368,6 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
         exclude = set(L.strip() for L in file(args["exclude"]))
     else: exclude = set()
 
-    myname = args["n"]
     basename = args["temp"]
     env.SConsignFile(os.path.join(env.GetLaunchDir(), basename, "sconsign"))
 
@@ -403,31 +384,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
             shutil.move(f,t)
         env.Exit(0)
 
-    ship = os.path.join(basename, "SHIP.tz2")
-    out = os.path.join(basename, "OUT.tz2")
-    force = os.path.join(basename, "IN.tz2")
     exe = os.path.join(basename, "EXECUTE")
     SIGNATURES = os.path.join(basename, ".sconsign.dblite")
-    ship_source = [s for s in sources if s not in exclude] + [exe, myname]
-
-    if "print" not in args and os.path.exists(force):
-        env.Execute("tar xjf " + force)
-        env.Execute("mv %s %s" % (force, out))
-        env.Exit(0)
-
-    env.Command(ship, ship_source, "tar cjf $TARGET $SOURCES")
-    env.Command(out, targets, "tar cjf $TARGET $SOURCES")
-
-    if args.get("print", None) == "sources":
-        for s in sources: print s
-        env.Exit(0)
-
-    if args.get("print", None) == "targets":
-        for t in targets: print t
-        env.Exit(0)
-
-    if args.get("print", None) == "ship":
-        for s in ship_source: print s
-        env.Exit(0)
 
     return targets, sources, basename
